==> magics++_2.8.0.dfsg.orig.tar.gz: magics++-2.8.0.dfsg/src/common/MetaData.cc <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file MetaData.h
    \brief Implementation of the Template class MetaData.
    
    Magics Team - ECMWF 2006
    
    Started: Thu 5-Jan-2006
    
    Changes:
    
*/



#include "MetaData.h"

using namespace magics;

MetaDataVisitor::MetaDataVisitor() 
{
	meta_.push_back(this);
}


MetaDataVisitor::~MetaDataVisitor() 
{
}

/*!
 Class information are given to the output-stream.
*/		
void MetaDataVisitor::print(ostream& out)  const
{
	out << "MetaData[";
	out << "]";
}


void MetaDataVisitor::close()
{
	//Log::dev() << " MetaData::write --->  " << meta << " in file[" << path_ << "]" << endl;
	ofstream out(path_.c_str());
	out << "<metadata>\n";
	for (const_iterator entry = begin(); entry != end(); ++entry)
		out << **entry;
	out << "</metadata>\n";
	out.close();
	
	
}

void MetaDataVisitor::collectMetaData()
{
	Log::dev() << "----MetaData::visit-----" << endl;
	parent_->visit(*this);
	close();

	ofstream out(javascript_.c_str());
	
	out << "(function(){" << endl;
	out        << "    var magics = {};" << endl;
	out        << "     var and = function (x, y) { return x && y; };" << endl;
	out        << "     var greater = function (x, y) { return x > y; };" << endl;
    out 	    <<  "     var smaller = function (x, y) { return x < y; };" << endl;
    out        << "     var equal = function (x, y) { return x == y; };"  << endl;
	                    
	for (map<string, string>::const_iterator web = web_.begin(); web != web_.end(); ++web) {
		out << "     " << web->first << " = " <<  web->second << "; " << endl;
		
	}
	/*
	out << "    magics.pan = function(dx, dy) { " << endl;
	out << "          var lower_left = reprojection(dx, bottom+dy); " << endl;
	out << "          var upper_right = reprojection(dx, bottom+dy); " << endl; 		
	out << "        return {" << endl;
    out << "            \"upper_right_longitude\":  
    "projection": , 
    "vertical_longitude": 0, 
    "lower_left_longitude": -37.270000000000003, 
    "lower_left_latitude": 21.510000000000002, 
    "upper_right_latitude": 51.280000000000001
} " << endl;
*/
	//out << "    };" << endl;
	out << "     return magics;" << endl;
	out << "})(); " << endl;
	out.close();
}

void MetaDataVisitor::metadata(map<string, string>& data)
{
    string quote = "\"";
	data["magics_version"] = quote + MAGICS_VERSION + quote;
    data["filename"] = javascript_;
    parent_->visit(*this);
    close();
}

vector<MetaDataVisitor*> MetaDataVisitor::meta_;

void MetaDataVisitor::collect() 
{
	for ( vector<MetaDataVisitor*>::iterator meta = meta_.begin(); meta != meta_.end(); ++meta ) 
		(*meta)->collectMetaData();
}

==> magics++_2.10.0.dfsg.orig.tar.gz: magics++-2.10.0.dfsg/src/common/MetaData.cc <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file MetaData.h
    \brief Implementation of the Template class MetaData.
    
    Magics Team - ECMWF 2006
    
    Started: Thu 5-Jan-2006
    
    Changes:
    
*/



#include "MetaData.h"
#include "Timer.h"

using namespace magics;

MetaDataVisitor::MetaDataVisitor() 
{
	meta_.push_back(this);
}


MetaDataVisitor::~MetaDataVisitor() 
{
}

/*!
 Class information are given to the output-stream.
*/		
void MetaDataVisitor::print(ostream& out)  const
{
	out << "MetaData[";
	out << "]";
}


void MetaDataVisitor::close()
{
	//Log::dev() << " MetaData::write --->  " << meta << " in file[" << path_ << "]" << endl;
	ofstream out(path_.c_str());
	out << "<metadata>\n";
	for (const_iterator entry = begin(); entry != end(); ++entry)
		out << **entry;
	out << "</metadata>\n";
	out.close();
	
	
}

void MetaDataVisitor::collectMetaData()
{
	Log::dev() << "----MetaData::visit-----" << endl;
	parent_->visit(*this);
	close();
	
	
	try {
	 ofstream out(profile_.c_str());
		
		out << "{" << endl;
		
		                    
		for (vector<ProfileInfo>::const_iterator web = Timer::begin(); web != Timer::end(); ++web) {
			out << *web << endl;
			
		}
		
		out << "}" << endl;
	}

	catch ( ...) {}
		

	ofstream out(javascript_.c_str());
	
	out        << "{";

	string s = "";
	                    
	for (map<string, string>::const_iterator web = web_.begin(); web != web_.end(); ++web) {
		
		out << s;
		out << "\"" << web->first << "\":" <<  web->second;
		s = ",";
	}

	out << "}";
	out.close();
}

void MetaDataVisitor::metadata(map<string, string>& data)
{
    string quote = "\"";
	data["magics_version"] = quote + MAGICS_VERSION + quote;
    data["filename"] = javascript_;
    parent_->visit(*this);
    close();
}

vector<MetaDataVisitor*> MetaDataVisitor::meta_;

void MetaDataVisitor::collect() 
{
	for ( vector<MetaDataVisitor*>::iterator meta = meta_.begin(); meta != meta_.end(); ++meta ) 
		(*meta)->collectMetaData();
}
